==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.2.0.zip: setup/lib/class.setupmask.php <==
<?php
/**
 * Project: 
 * Contenido Content Management System
 * 
 * Description: 
 * 
 * Requirements: 
 * @con_php_req 5
 *
 * @package    ContenidoBackendArea
 * @version    0.2
 * @author     unknown
 * @copyright  four for business AG <www.4fb.de>
 * @license    http://www.contenido.org/license/LIZENZ.txt
 * @link       http://www.4fb.de
 * @link       http://www.contenido.org
 * 
 * 
 * 
 * {@internal 
 *   created  unknown
 *   modified 2008-07-07, bilal arslan, added security fix
 *
 *   $Id$:
 * }}
 * 
 */
if(!defined('CON_FRAMEWORK')) {
   die('Illegal call');
}

class cSetupMask {
	function __construct($sStepTemplate, $iStep = false) {
		$this->_oTpl = new Template;
		$this->_oStepTemplate = new Template;
		
		$this->_sStepTemplate = $sStepTemplate;
		$this->_iStep = $iStep;
		$this->_bNavigationEnabled = false;
	}
	
	function setNavigation($sBackstep, $sNextstep) {
		$this->_bNavigationEnabled = true;
		$this->_bBackstep = $sBackstep;
		$this->_bNextstep = $sNextstep;
	}
	
	function setHeader($sHeader) {
		if (array_key_exists("setuptype", $_SESSION)) {
			$sSetupType = $_SESSION["setuptype"];
		} else {
			$sSetupType = "";	
		}
		
		switch ($sSetupType) {
			case "setup":
				$this->_sHeader = i18n_setup("Setup") . " - " . $sHeader;
				break;
			case "upgrade":
				$this->_sHeader = i18n_setup("Upgrade") . " - " . $sHeader;
				break;					
			case "migration":
				$this->_sHeader = i18n_setup("Migration") . " - " . $sHeader;
				break;
			default:
				$this->_sHeader = $sHeader;
				break;
		}
	}
	
	function _createNavigation () {
		if ($this->_bNextstep != "") {
			$this->_oStepTemplate->set("s", "NEXT", '<input id="Next" type="image" src="../admin/images/submit.gif" style="width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'../admin/images/submit.gif\');" onmouseout="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit.gif\\\');\'; } else { this.src=\'../admin/images/submit.gif\'; }" onmouseover="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit_hover.gif\\\');\'; } else { this.src=\'../admin/images/submit_hover.gif\'; }" onload="this.imgnormal = \'../admin/images/submit.gif\'; this.imgover = \'../admin/images/submit_hover.gif\'; this.clickimgnormal = \'\'; this.clickimgover = \'\'; if (!this.init) {IEAlphaInit(this); IEAlphaApply(this, this.imgnormal); this.init = true;}" onclick="document.setupform.step.value = \''.$this->_bNextstep.'\';">');
		} else {
			$this->_oStepTemplate->set("s", "NEXT", '');
		}
		
		if ($this->_bBackstep != "") {
			$this->_oStepTemplate->set("s", "BACK", '<input id="Prev" type="image" src="images/controls/back.gif" style="margin-right: 10px; width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'images/controls/back.gif\');" onclick="document.setupform.step.value = \''.$this->_bBackstep.'\';">');
		} else {
			$this->_oStepTemplate->set("s", "BACK", '');
		}
	}
	
	function render() {
		if ($this->_bNavigationEnabled) {
			$this->_createNavigation();
		}
		
		if ($this->_iStep !== false) {
			$this->_oTpl->set("s", "STEPS", cGenerateSetupStepsDisplay($this->_iStep));
		} else {
			$this->_oTpl->set("s", "STEPS", "");
		}
		
		$this->_oTpl->set("s", "HEADER", $this->_sHeader);
		$this->_oTpl->set("s", "BRIGHT", i18n_setup("bright mode"));
		$this->_oTpl->set("s", "DARK", i18n_setup("dark mode"));
        $this->_oTpl->set('s', 'INFO', i18n_setup('The Must Have Content Management System'));
		$this->_oTpl->set("s", "TITLE", "DZIRCMS Setup - " . $this->_sHeader);
        
		$this->_oTpl->set("s", "CONTENT", $this->_oStepTemplate->generate($this->_sStepTemplate, true, false));
        
		$this->_oTpl->generate("templates/setup.tpl",false,false);
	}
}
?>

==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.3.2.zip: setup/lib/class.setupmask.php <==
<?php
/**
 * Project: 
 * Contenido Content Management System
 * 
 * Description: 
 * 
 * Requirements: 
 * @con_php_req 5
 *
 * @package    ContenidoBackendArea
 * @version    0.2
 * @author     unknown
 * @copyright  four for business AG <www.4fb.de>
 * @license    http://www.contenido.org/license/LIZENZ.txt
 * @link       http://www.4fb.de
 * @link       http://www.contenido.org
 * 
 * 
 * 
 * {@internal 
 *   created  unknown
 *   modified 2008-07-07, bilal arslan, added security fix
 *
 *   $Id$:
 * }}
 * 
 */
if(!defined('CON_FRAMEWORK')) {
   die('Illegal call');
}

class cSetupMask {
	var $_oTpl;
	var $_oStepTemplate;
	var $_sStepTemplate;
	var $_iStep;
	var $_bNavigationEnabled;
	var $_bBackstep, $_bNextstep;
	var $_sHeader, $_sTitle, $_iYear;

	function __construct($sStepTemplate, $iStep = false) {
		$this->_oTpl = new Template;
		$this->_oStepTemplate = new Template;
		
		$this->_sStepTemplate = $sStepTemplate;
		$this->_iStep = $iStep;
		$this->_bNavigationEnabled = false;
	}
	
	function setNavigation($sBackstep, $sNextstep) {
		$this->_bNavigationEnabled = true;
		$this->_bBackstep = $sBackstep;
		$this->_bNextstep = $sNextstep;
	}
	
	function setHeader($sHeader) {
		if (array_key_exists("setuptype", $_SESSION)) {
			$sSetupType = $_SESSION["setuptype"];
		} else {
			$sSetupType = "";	
		}
		
		switch ($sSetupType) {
			case "setup":
				$this->_sHeader = i18n_setup("Setup") . " - " . $sHeader;
				break;
			case "upgrade":
				$this->_sHeader = i18n_setup("Upgrade") . " - " . $sHeader;
				break;					
			case "migration":
				$this->_sHeader = i18n_setup("Migration") . " - " . $sHeader;
				break;
			default:
				$this->_sHeader = $sHeader;
				break;
		}
	}

	function setTitle($sTitle) {
		$this->_sTitle = $sTitle;
	}

	function setYear($year) {
		$this->_iYear = (int) $year;
	}
	
	function _createNavigation () {
		if ($this->_bNextstep != "") {
			$this->_oStepTemplate->set("s", "NEXT", '<input id="Next" type="image" src="../admin/images/submit.gif" style="width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'../admin/images/submit.gif\');" onmouseout="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit.gif\\\');\'; } else { this.src=\'../admin/images/submit.gif\'; }" onmouseover="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit_hover.gif\\\');\'; } else { this.src=\'../admin/images/submit_hover.gif\'; }" onload="this.imgnormal = \'../admin/images/submit.gif\'; this.imgover = \'../admin/images/submit_hover.gif\'; this.clickimgnormal = \'\'; this.clickimgover = \'\'; if (!this.init) {IEAlphaInit(this); IEAlphaApply(this, this.imgnormal); this.init = true;}" onclick="document.setupform.step.value = \''.$this->_bNextstep.'\';">');
		} else {
			$this->_oStepTemplate->set("s", "NEXT", '');
		}
		
		if ($this->_bBackstep != "") {
			$this->_oStepTemplate->set("s", "BACK", '<input id="Prev" type="image" src="images/controls/back.gif" style="margin-right: 10px; width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'images/controls/back.gif\');" onclick="document.setupform.step.value = \''.$this->_bBackstep.'\';">');
		} else {
			$this->_oStepTemplate->set("s", "BACK", '');
		}
	}
	
	function render() {
		if ($this->_bNavigationEnabled) {
			$this->_createNavigation();
		}
		
		if ($this->_iStep !== false) {
			$this->_oTpl->set("s", "STEPS", cGenerateSetupStepsDisplay($this->_iStep));
		} else {
			$this->_oTpl->set("s", "STEPS", "");
		}
		
		$this->_oTpl->set("s", "HEADER", $this->_sHeader);
		$this->_oTpl->set("s", "YEAR", $this->_iYear);
		$this->_oTpl->set("s", "BRIGHT", i18n_setup("bright mode"));
		$this->_oTpl->set("s", "DARK", i18n_setup("dark mode"));
        $this->_oTpl->set('s', 'INFO', i18n_setup('The Must Have Content Management System'));
		$this->_oTpl->set("s", "TITLE", sprintf('DZIRCMS %s Setup', $this->_sTitle));
        
		$this->_oTpl->set("s", "CONTENT", $this->_oStepTemplate->generate($this->_sStepTemplate, true, false));
        
		$this->_oTpl->generate("templates/setup.tpl",false,false);
	}
}
?>
